@@ -22,7 +22,8 @@
 #include <config.h>
 #include <glib-object.h>
 
-#include <gnome.h>
+#include <glib/gi18n.h>
+
 #include <stdio.h>
 #include <unistd.h>
 #include <sys/stat.h>
@@ -69,9 +70,9 @@ static struct {
 
 
 
-GType hex_dialog_get_type ()
+GType hex_dialog_get_type (void)
 {
-    static GtkType doc_type = 0;
+    static GType doc_type = 0;
 
     if (doc_type == 0)
     {
@@ -114,7 +115,7 @@ static void hex_dialog_class_init (HexDialogClass *klass)
 {
 }
 
-HexDialog *hex_dialog_new()
+HexDialog *hex_dialog_new (void)
 {
     HexDialog *dialog;
 
@@ -170,10 +171,10 @@ GtkWidget *hex_dialog_getview(HexDialog *dialog)
     gtk_widget_show(table);
     gtk_widget_show(vbox);
 
-    gtk_box_pack_start(GTK_BOX(vbox), table, TRUE, FALSE, GNOME_PAD_SMALL);
+    gtk_box_pack_start(GTK_BOX(vbox), table, TRUE, FALSE, 4);
 
-    gtk_table_set_row_spacings(GTK_TABLE(table), GNOME_PAD_SMALL);
-    gtk_table_set_col_spacings(GTK_TABLE(table), GNOME_PAD_SMALL);
+    gtk_table_set_row_spacings(GTK_TABLE(table), 4);
+    gtk_table_set_col_spacings(GTK_TABLE(table), 4);
 
     create_dialog_prop(S8, dialog, table, 0, 0);
     create_dialog_prop(US8, dialog, table, 0, 1);
@@ -190,7 +191,7 @@ GtkWidget *hex_dialog_getview(HexDialog *dialog)
     create_dialog_prop(BIN, dialog, table, 4, 2);
 
     hbox = gtk_hbox_new(FALSE, 0);
-    gtk_box_pack_start(GTK_BOX(vbox), hbox, TRUE, FALSE, GNOME_PAD_SMALL);
+    gtk_box_pack_start(GTK_BOX(vbox), hbox, TRUE, FALSE, 4);
     gtk_widget_show(hbox);
 
     dialog->config_endian = gtk_check_button_new_with_label(_("Show little endian decoding"));
@@ -198,20 +199,20 @@ GtkWidget *hex_dialog_getview(HexDialog *dialog)
     g_signal_connect(G_OBJECT(dialog->config_endian), "toggled",
                      G_CALLBACK(config_toggled_cb), dialog);
     gtk_widget_show(dialog->config_endian);
-    gtk_box_pack_start(GTK_BOX(hbox), dialog->config_endian, TRUE, FALSE, GNOME_PAD_SMALL);
+    gtk_box_pack_start(GTK_BOX(hbox), dialog->config_endian, TRUE, FALSE, 4);
 
     dialog->config_hex = gtk_check_button_new_with_label(_("Show unsigned and float as hexadecimal"));
     g_signal_connect(G_OBJECT(dialog->config_hex), "toggled",
                      G_CALLBACK(config_toggled_cb), dialog);
     gtk_widget_show(dialog->config_hex);
-    gtk_box_pack_start(GTK_BOX(hbox), dialog->config_hex, TRUE, FALSE, GNOME_PAD_SMALL);
+    gtk_box_pack_start(GTK_BOX(hbox), dialog->config_hex, TRUE, FALSE, 4);
 
     label = gtk_label_new(_("Stream Length:"));
     gtk_misc_set_alignment(GTK_MISC(label), 0.0, 0.5);
     gtk_table_attach_defaults(GTK_TABLE(table), label, 4, 5, 3, 4);
     gtk_widget_show(label);
 
-    adjuster = (GtkAdjustment *)gtk_adjustment_new(8.0, 1.0, 32.0, 1.0, 8.0, 8.0);
+    adjuster = (GtkAdjustment *)gtk_adjustment_new(8.0, 1.0, 32.0, 1.0, 8.0, 0);
     spin = gtk_spin_button_new(adjuster, 1.0, 0);
     g_signal_connect(G_OBJECT(spin), "value-changed",
                      G_CALLBACK(config_spinchange_cb), dialog);
@@ -262,7 +263,7 @@ static char convbuffer[CONV_BUFSIZE];
  * also makes it endian safe (i think)
  */
 
-unsigned int pow2(int p)
+static unsigned int pow2(int p)
 {
     unsigned int i = 0, r = 1;
     for (i = 0; i < p; i++)
@@ -270,16 +271,6 @@ unsigned int pow2(int p)
     return r;
 }
 
-double fpow10(int p)
-{
-    return pow(10, p);
-}
-
-double fpow2(int p)
-{
-    return pow(2.0, p);
-}
-
 char *HexConvert_S8(HexDialogVal64 *val, HexConversionProperties *prop)
 {
     int i, local = 0;
