@@ -26,18 +26,16 @@
 #endif /* HAVE_CONFIG_H */
 
 #include <gtk/gtk.h>
+#include <glib/gi18n.h>
 
-#include <libgnomeprintui/gnome-font-dialog.h>
-
-#include "gnome-print-font-picker.h"
 #include "preferences.h"
 #include "configuration.h"
 #include "ghex-window.h"
+#include "ui.h"
 
 #define MAX_MAX_UNDO_DEPTH 100000
 
-static void select_font_cb(GtkWidget *w, const gchar *font_name,
-						   PropertyUI *pui);
+static void select_font_cb(GtkWidget *w, PropertyUI *pui);
 static void select_display_font_cb(GtkWidget *w, PropertyUI *pui);
 static void max_undo_changed_cb(GtkAdjustment *adj, PropertyUI *pui);
 static void box_size_changed_cb(GtkAdjustment *adj, PropertyUI *pui);
@@ -87,7 +85,7 @@ create_prefs_dialog()
 
 	notebook = gtk_notebook_new();
 	gtk_widget_show(notebook);
-	gtk_container_add(GTK_CONTAINER(GTK_DIALOG(pui->pbox)->vbox), notebook);
+	gtk_container_add(GTK_CONTAINER(gtk_dialog_get_content_area(GTK_DIALOG(pui->pbox))), notebook);
 
 	/* editing page */
 	vbox = gtk_vbox_new(FALSE, 0);
@@ -102,14 +100,14 @@ create_prefs_dialog()
 
 	label = gtk_label_new_with_mnemonic(_("_Maximum number of undo levels:"));
 	gtk_misc_set_alignment(GTK_MISC(label), 0.0, 0.5);
-	gtk_box_pack_start (GTK_BOX(box), label, TRUE, TRUE, GNOME_PAD);
+	gtk_box_pack_start (GTK_BOX(box), label, TRUE, TRUE, 8);
 	gtk_widget_show(label);
 						  
 	pui->undo_spin = gtk_spin_button_new(undo_adj, 1, 0);
-	gtk_box_pack_end (GTK_BOX(box), GTK_WIDGET(pui->undo_spin), FALSE, TRUE, GNOME_PAD);
+	gtk_box_pack_end (GTK_BOX(box), GTK_WIDGET(pui->undo_spin), FALSE, TRUE, 8);
 	gtk_widget_show(pui->undo_spin);
 
-	gtk_box_pack_start(GTK_BOX(vbox), box, FALSE, TRUE, GNOME_PAD);
+	gtk_box_pack_start(GTK_BOX(vbox), box, FALSE, TRUE, 8);
 
 	/* cursor offset format */
 	box = gtk_hbox_new(FALSE, 0);
@@ -126,7 +124,7 @@ create_prefs_dialog()
 
 	label = gtk_label_new_with_mnemonic(_("_Show cursor offset in statusbar as:"));
 	gtk_misc_set_alignment(GTK_MISC(label), 0.0, 0.5);
-	gtk_box_pack_start (GTK_BOX(box), label, TRUE, TRUE, GNOME_PAD);
+	gtk_box_pack_start (GTK_BOX(box), label, TRUE, TRUE, 8);
 	gtk_widget_show(label);
 
 	pui->format = gtk_entry_new();
@@ -134,24 +132,24 @@ create_prefs_dialog()
 					 G_CALLBACK(format_activated_cb), pui);
 	g_signal_connect(G_OBJECT(pui->format), "focus_out_event",
 					 G_CALLBACK(format_focus_out_event_cb), pui);
-	gtk_box_pack_start (GTK_BOX(box), pui->format, TRUE, TRUE, GNOME_PAD);
+	gtk_box_pack_start (GTK_BOX(box), pui->format, TRUE, TRUE, 8);
 	gtk_widget_show(pui->format);
 
-	pui->offset_menu = gtk_combo_box_new_text();
+	pui->offset_menu = gtk_combo_box_text_new();
 	gtk_label_set_mnemonic_widget (GTK_LABEL(label), pui->offset_menu);
 	gtk_widget_show(pui->offset_menu);
-	gtk_combo_box_append_text(GTK_COMBO_BOX(pui->offset_menu),
-							  _("Decimal"));
-	gtk_combo_box_append_text(GTK_COMBO_BOX(pui->offset_menu),
-							  _("Hexadecimal"));
-	gtk_combo_box_append_text(GTK_COMBO_BOX(pui->offset_menu),
-							  _("Custom"));
+	gtk_combo_box_text_append_text(GTK_COMBO_BOX_TEXT(pui->offset_menu),
+								   _("Decimal"));
+	gtk_combo_box_text_append_text(GTK_COMBO_BOX_TEXT(pui->offset_menu),
+								   _("Hexadecimal"));
+	gtk_combo_box_text_append_text(GTK_COMBO_BOX_TEXT(pui->offset_menu),
+								   _("Custom"));
 	g_signal_connect(G_OBJECT(pui->offset_menu), "changed",
 					 G_CALLBACK(offset_cb), pui);
 	gtk_box_pack_end(GTK_BOX(box), GTK_WIDGET(pui->offset_menu),
-					 FALSE, TRUE, GNOME_PAD);
+					 FALSE, TRUE, 8);
 
-	gtk_box_pack_start(GTK_BOX(vbox), box, FALSE, TRUE, GNOME_PAD_SMALL);
+	gtk_box_pack_start(GTK_BOX(vbox), box, FALSE, TRUE, 4);
 
 	if (gail_up) {
 		add_atk_namedesc (pui->format, "format_entry", _("Enter the cursor offset format"));
@@ -167,7 +165,7 @@ create_prefs_dialog()
 	/* show offsets check button */
 	pui->offsets_col = gtk_check_button_new_with_mnemonic(_("Sh_ow offsets column"));
 	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(pui->offsets_col), show_offsets_column);
-	gtk_box_pack_start(GTK_BOX(vbox), pui->offsets_col, FALSE, TRUE, GNOME_PAD_SMALL);
+	gtk_box_pack_start(GTK_BOX(vbox), pui->offsets_col, FALSE, TRUE, 4);
 	gtk_widget_show(pui->offsets_col);
 
 	label = gtk_label_new(_("Editing"));
@@ -180,30 +178,30 @@ create_prefs_dialog()
 	
 	/* display font */
 	frame = gtk_frame_new(_("Font"));
-	gtk_container_set_border_width(GTK_CONTAINER(frame), GNOME_PAD_SMALL);
+	gtk_container_set_border_width(GTK_CONTAINER(frame), 4);
 	gtk_widget_show(frame);
 	
 	fbox = gtk_hbox_new(0, 5);
 	pui->font_button = gtk_font_button_new();
 	gtk_font_button_set_font_name(GTK_FONT_BUTTON(pui->font_button),
 								  def_font_name);
-	gtk_signal_connect (GTK_OBJECT (pui->font_button), "font-set",
-						GTK_SIGNAL_FUNC (select_display_font_cb), pui);
+	g_signal_connect (pui->font_button, "font-set",
+	                  G_CALLBACK (select_display_font_cb), pui);
 	flabel = gtk_label_new("");
 	gtk_label_set_mnemonic_widget (GTK_LABEL (flabel), pui->font_button);
 	gtk_widget_show(flabel);
 	gtk_widget_show(GTK_WIDGET(pui->font_button));
-	gtk_container_set_border_width(GTK_CONTAINER(fbox), GNOME_PAD_SMALL);
-	gtk_box_pack_start (GTK_BOX (fbox), GTK_WIDGET(pui->font_button), FALSE, TRUE, GNOME_PAD_BIG);
+	gtk_container_set_border_width(GTK_CONTAINER(fbox), 4);
+	gtk_box_pack_start (GTK_BOX (fbox), GTK_WIDGET(pui->font_button), FALSE, TRUE, 12);
 	
 	gtk_widget_show(fbox);
 	gtk_container_add(GTK_CONTAINER(frame), GTK_WIDGET(fbox));
 	
-	gtk_box_pack_start(GTK_BOX(vbox), frame, TRUE, TRUE, GNOME_PAD_SMALL);
+	gtk_box_pack_start(GTK_BOX(vbox), frame, TRUE, TRUE, 4);
 	
 	/* default group type */
 	frame = gtk_frame_new(_("Default Group Type"));
-	gtk_container_set_border_width(GTK_CONTAINER(frame), GNOME_PAD_SMALL);
+	gtk_container_set_border_width(GTK_CONTAINER(frame), 4);
 	gtk_widget_show(frame);
 
 	box = gtk_vbox_new(FALSE, 0);
@@ -216,7 +214,7 @@ create_prefs_dialog()
 		group = gtk_radio_button_get_group(pui->group_type[i]);
 	}
 	gtk_container_add(GTK_CONTAINER(frame), box);
-	gtk_box_pack_start(GTK_BOX(vbox), frame, TRUE, TRUE, GNOME_PAD_SMALL);
+	gtk_box_pack_start(GTK_BOX(vbox), frame, TRUE, TRUE, 4);
 	
 	label = gtk_label_new(_("Display"));
 	gtk_widget_show(label);
@@ -228,12 +226,12 @@ create_prefs_dialog()
 
 	/* paper selection */
 	frame = gtk_frame_new(_("Paper size"));
-	gtk_container_set_border_width(GTK_CONTAINER(frame), GNOME_PAD_SMALL);
+	gtk_container_set_border_width(GTK_CONTAINER(frame), 4);
 	gtk_widget_show(frame);
 
 	/* data & header font selection */
 	frame = gtk_frame_new(_("Fonts"));
-	gtk_container_set_border_width(GTK_CONTAINER(frame), GNOME_PAD_SMALL);
+	gtk_container_set_border_width(GTK_CONTAINER(frame), 4);
 	gtk_widget_show(frame);
 
 	table = gtk_table_new(2, 3, TRUE);
@@ -243,12 +241,9 @@ create_prefs_dialog()
 	gtk_widget_show(label);
 	gtk_table_attach(GTK_TABLE(table), label, 0, 1, 0, 1,
 					 GTK_FILL, GTK_FILL,
-					 GNOME_PAD_SMALL, GNOME_PAD_SMALL);
+					 4, 4);
 
-	pui->df_button = gnome_print_font_picker_new();
-	gnome_print_font_picker_set_mode (GNOME_PRINT_FONT_PICKER (pui->df_button), GNOME_PRINT_FONT_PICKER_MODE_FONT_INFO);
-	gnome_print_font_picker_fi_set_use_font_in_label (GNOME_PRINT_FONT_PICKER (pui->df_button), TRUE, 14);
-	gnome_print_font_picker_fi_set_show_size (GNOME_PRINT_FONT_PICKER (pui->df_button), TRUE);
+	pui->df_button = gtk_font_button_new_with_font(def_font_name);
 	g_signal_connect (G_OBJECT (pui->df_button), "font_set",
 					  G_CALLBACK (select_font_cb), pui);
 	pui->df_label = gtk_label_new("");
@@ -264,23 +259,20 @@ create_prefs_dialog()
 	gtk_widget_show(pui->df_button);
 	gtk_table_attach(GTK_TABLE(table), pui->df_button, 1, 2, 0, 1,
 					 GTK_EXPAND | GTK_SHRINK | GTK_FILL, GTK_FILL,
-					 GNOME_PAD_SMALL, GNOME_PAD_SMALL);
+					 4, 4);
 	label = gtk_label_new("");
 	gtk_widget_show(label);
 	gtk_table_attach(GTK_TABLE(table), label, 2, 3, 0, 1,
 					 GTK_EXPAND | GTK_SHRINK | GTK_FILL, GTK_FILL,
-					 GNOME_PAD_SMALL, GNOME_PAD_SMALL);
+					 4, 4);
 
 	label = gtk_label_new_with_mnemonic(_("Header fo_nt:"));
 	gtk_misc_set_alignment(GTK_MISC(label), 0.0, 0.5);
 	gtk_widget_show(label);
 	gtk_table_attach(GTK_TABLE(table), label, 0, 1, 1, 2,
 					 GTK_FILL, GTK_FILL,
-					 GNOME_PAD_SMALL, GNOME_PAD_SMALL);
-	pui->hf_button = gnome_print_font_picker_new();
-	gnome_print_font_picker_set_mode (GNOME_PRINT_FONT_PICKER (pui->hf_button), GNOME_PRINT_FONT_PICKER_MODE_FONT_INFO);
-	gnome_print_font_picker_fi_set_use_font_in_label (GNOME_PRINT_FONT_PICKER (pui->hf_button), TRUE, 14);
-	gnome_print_font_picker_fi_set_show_size (GNOME_PRINT_FONT_PICKER (pui->hf_button), TRUE);
+					 4, 4);
+	pui->hf_button = gtk_font_button_new_with_font(def_font_name);
 	g_signal_connect (G_OBJECT (pui->hf_button), "font_set",
 					  G_CALLBACK (select_font_cb), pui);
 	pui->hf_label = gtk_label_new("");
@@ -296,18 +288,18 @@ create_prefs_dialog()
 	gtk_widget_show(pui->hf_button);
 	gtk_table_attach(GTK_TABLE(table), pui->hf_button, 1, 2, 1, 2,
 					 GTK_EXPAND | GTK_SHRINK | GTK_FILL, GTK_FILL,
-					 GNOME_PAD_SMALL, GNOME_PAD_SMALL);
+					 4, 4);
 
 	label = gtk_label_new("");
 	gtk_widget_show(label);
 	gtk_table_attach(GTK_TABLE(table), label, 2, 3, 1, 2,
 					 GTK_EXPAND | GTK_SHRINK | GTK_FILL, GTK_FILL,
-					 GNOME_PAD_SMALL, GNOME_PAD_SMALL);
+					 4, 4);
 
 	gtk_container_add(GTK_CONTAINER(frame), table);
 
 	gtk_box_pack_start(GTK_BOX(vbox), frame, TRUE, TRUE,
-					   GNOME_PAD_SMALL);  
+					   4);
 
 	/* shaded box entry */
 	box_adj = GTK_ADJUSTMENT(gtk_adjustment_new(0, 0, 1000, 1, 10, 0));
@@ -317,11 +309,11 @@ create_prefs_dialog()
 
 	label = gtk_label_new_with_mnemonic(_("_Print shaded box over:"));
 	gtk_misc_set_alignment(GTK_MISC(label), 1.0, 0.5);
-	gtk_box_pack_start (GTK_BOX(box), label, TRUE, TRUE, GNOME_PAD_SMALL);
+	gtk_box_pack_start (GTK_BOX(box), label, TRUE, TRUE, 4);
 	gtk_widget_show(label);
 						  
 	pui->box_size_spin = gtk_spin_button_new(box_adj, 1, 0);
-	gtk_box_pack_start (GTK_BOX(box), GTK_WIDGET(pui->box_size_spin), FALSE, TRUE, GNOME_PAD);
+	gtk_box_pack_start (GTK_BOX(box), GTK_WIDGET(pui->box_size_spin), FALSE, TRUE, 8);
 	gtk_widget_show(pui->box_size_spin);
 
 	gtk_label_set_mnemonic_widget (GTK_LABEL (label), pui->box_size_spin);
@@ -333,10 +325,10 @@ create_prefs_dialog()
 
 	label = gtk_label_new(_("lines (0 for no box)"));
 	gtk_misc_set_alignment(GTK_MISC(label), 0.0, 0.5);
-	gtk_box_pack_start (GTK_BOX(box), label, FALSE, TRUE, GNOME_PAD_SMALL);
+	gtk_box_pack_start (GTK_BOX(box), label, FALSE, TRUE, 4);
 	gtk_widget_show(label);
 
-	gtk_box_pack_start(GTK_BOX(vbox), box, TRUE, TRUE, GNOME_PAD_SMALL);  
+	gtk_box_pack_start(GTK_BOX(vbox), box, TRUE, TRUE, 4);
 
 	label = gtk_label_new(_("Printing"));
 	gtk_widget_show(label);
@@ -381,12 +373,10 @@ void set_current_prefs(PropertyUI *pui) {
 	}
 
 	if(header_font_name)
-		gnome_print_font_picker_set_font_name
-			(GNOME_PRINT_FONT_PICKER(pui->hf_button),
+		gtk_font_button_set_font_name(GTK_FONT_BUTTON(pui->hf_button),
 			 header_font_name);
 	if(data_font_name)
-		gnome_print_font_picker_set_font_name
-			(GNOME_PRINT_FONT_PICKER(pui->df_button),
+		gtk_font_button_set_font_name(GTK_FONT_BUTTON(pui->df_button),
 			 data_font_name);
 	if(def_font_name)
 		gtk_font_button_set_font_name(GTK_FONT_BUTTON(pui->font_button),
@@ -398,26 +388,26 @@ void set_current_prefs(PropertyUI *pui) {
 static void
 max_undo_changed_cb(GtkAdjustment *adj, PropertyUI *pui)
 {
-	if((guint)adj->value != max_undo_depth) {
+	if((guint)gtk_adjustment_get_value(adj) != max_undo_depth) {
 		max_undo_depth = gtk_spin_button_get_value_as_int
 			(GTK_SPIN_BUTTON(pui->undo_spin));
-		gconf_client_set_int (gconf_client,
-							  GHEX_BASE_KEY GHEX_PREF_MAX_UNDO_DEPTH,
-							  max_undo_depth,
-							  NULL);
+		g_settings_set (settings,
+		                GHEX_PREF_MAX_UNDO_DEPTH,
+		                "u",
+		                max_undo_depth);
 	}
 }
 
 static void
 box_size_changed_cb(GtkAdjustment *adj, PropertyUI *pui)
 {
-	if((guint)adj->value != shaded_box_size) {
+	if((guint)gtk_adjustment_get_value(adj) != shaded_box_size) {
 		shaded_box_size = gtk_spin_button_get_value_as_int
 			(GTK_SPIN_BUTTON(pui->box_size_spin));
-		gconf_client_set_int (gconf_client,
-							  GHEX_BASE_KEY GHEX_PREF_BOX_SIZE,
-							  shaded_box_size,
-							  NULL);
+		g_settings_set (settings,
+		                GHEX_PREF_BOX_SIZE,
+		                "u",
+		                shaded_box_size);
 	}
 }
 
@@ -426,10 +416,9 @@ offsets_col_cb(GtkToggleButton *tb, PropertyUI *pui)
 {
 	show_offsets_column = gtk_toggle_button_get_active
 		(GTK_TOGGLE_BUTTON(pui->offsets_col));
-	gconf_client_set_bool (gconf_client,
-						   GHEX_BASE_KEY GHEX_PREF_OFFSETS_COLUMN,
-						   show_offsets_column,
-						   NULL);	
+	g_settings_set_boolean (settings,
+	                        GHEX_PREF_OFFSETS_COLUMN,
+	                        show_offsets_column);
 }
 
 static void
@@ -438,14 +427,13 @@ group_type_cb(GtkRadioButton *rd, PropertyUI *pui)
 	int i;
 
 	for(i = 0; i < 3; i++)
-		if(GTK_TOGGLE_BUTTON(pui->group_type[i])->active) {
+		if(gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(pui->group_type[i]))) {
 			def_group_type = group_type[i];
 			break;
 		}
-	gconf_client_set_int (gconf_client,
-						  GHEX_BASE_KEY GHEX_PREF_GROUP,
-						  def_group_type,
-						  NULL);
+	g_settings_set_enum (settings,
+	                     GHEX_PREF_GROUP,
+	                     def_group_type);
 }
 
 static void
@@ -455,7 +443,7 @@ prefs_response_cb(GtkDialog *dlg, gint response, PropertyUI *pui)
 
 	switch(response) {
 	case GTK_RESPONSE_HELP:
-		gnome_help_display("ghex2.xml", "ghex-prefs", &error);
+		gtk_show_uri (NULL, "ghelp:ghex?ghex-prefs",  gtk_get_current_event_time (), &error);
 		if(NULL != error) {
 			GtkWidget *dialog;
 			dialog = gtk_message_dialog_new
@@ -466,7 +454,8 @@ prefs_response_cb(GtkDialog *dlg, gint response, PropertyUI *pui)
 							 G_CALLBACK (gtk_widget_destroy),
 							 NULL);
 			gtk_window_set_resizable(GTK_WINDOW (dialog), FALSE);
-			gtk_widget_show(dialog);
+			gtk_window_present (GTK_WINDOW (dialog));
+
 			g_error_free(error);
 		}
 		break;
@@ -505,10 +494,9 @@ select_display_font_cb(GtkWidget *w, PropertyUI *pui)
 				(gtk_font_button_get_font_name
 				 (GTK_FONT_BUTTON(pui->font_button)));
 			def_font_desc = new_desc;
-			gconf_client_set_string (gconf_client,
-									 GHEX_BASE_KEY GHEX_PREF_FONT,
-									 def_font_name,
-									 NULL);
+			g_settings_set_string (settings,
+			                       GHEX_PREF_FONT,
+			                       def_font_name);
 		}
 		else
 			display_error_dialog (ghex_window_get_active(),
@@ -517,27 +505,25 @@ select_display_font_cb(GtkWidget *w, PropertyUI *pui)
 }
 
 static void
-select_font_cb(GtkWidget *w, const gchar *font_name, PropertyUI *pui)
+select_font_cb(GtkWidget *w, PropertyUI *pui)
 {
 	if(w == pui->df_button) {
 		if(data_font_name)
 			g_free(data_font_name);
-		data_font_name = g_strdup(gnome_print_font_picker_get_font_name
-								  (GNOME_PRINT_FONT_PICKER (pui->df_button)));
-		gconf_client_set_string (gconf_client,
-								 GHEX_BASE_KEY GHEX_PREF_DATA_FONT,
-								 data_font_name,
-								 NULL);
+		data_font_name = g_strdup(gtk_font_button_get_font_name
+								  (GTK_FONT_BUTTON (pui->df_button)));
+		g_settings_set_string (settings,
+		                       GHEX_PREF_DATA_FONT,
+		                       data_font_name);
 	}
 	else if(w == pui->hf_button) {
 		if(header_font_name)
 			g_free(header_font_name);
-		header_font_name = g_strdup(gnome_print_font_picker_get_font_name
-									(GNOME_PRINT_FONT_PICKER (pui->hf_button)));
-		gconf_client_set_string (gconf_client,
-								 GHEX_BASE_KEY GHEX_PREF_HEADER_FONT,
-								 header_font_name,
-								 NULL);
+		header_font_name = g_strdup(gtk_font_button_get_font_name
+									(GTK_FONT_BUTTON (pui->hf_button)));
+		g_settings_set_string (settings,
+		                       GHEX_PREF_HEADER_FONT,
+		                       header_font_name);
 	}
 }
 
@@ -586,10 +572,9 @@ update_offset_fmt_from_entry(GtkEntry *entry, PropertyUI *pui)
 	}
 	if(offset_fmt != old_offset_fmt)
 		g_free(old_offset_fmt);
-	gconf_client_set_string (gconf_client,
-							 GHEX_BASE_KEY GHEX_PREF_OFFSET_FORMAT,
-							 offset_fmt,
-							 NULL);
+	g_settings_set_string (settings,
+	                       GHEX_PREF_OFFSET_FORMAT,
+	                       offset_fmt);
 	win_list = ghex_window_get_list();
 	while(NULL != win_list) {
 		ghex_window_update_status_message((GHexWindow *)win_list->data);
